@@ -24,13 +24,14 @@
 from ...utils.importlib import require_modules
 
 
-required_modules = ['cassandra.cluster']
+required_modules = ["cassandra.cluster"]
 
 with require_modules(required_modules) as missing_modules:
     if not missing_modules:
         from .session import get_traced_cassandra
         from .session import patch
+
         __all__ = [
-            'get_traced_cassandra',
-            'patch',
+            "get_traced_cassandra",
+            "patch",
         ]
