@@ -11,6 +11,10 @@ file read by pytest (``pytest.ini``, ``setup.cfg``, ...)::
     [pytest]
     ddtrace = 1
 
+You can enable all integrations by using the ``--ddtrace-patch-all`` option or by adding this to your configuration::
+
+    [pytest]
+    ddtrace-patch-all = 1
 
 Global Configuration
 ~~~~~~~~~~~~~~~~~~~~
@@ -39,6 +43,7 @@ from ddtrace import config
 
 from ...utils.formats import get_env
 
+
 # pytest default settings
 config._add(
     "pytest",
