@@ -46,6 +46,7 @@ required_modules = ["vertica_python"]
 
 with require_modules(required_modules) as missing_modules:
     if not missing_modules:
-        from .patch import patch, unpatch
+        from .patch import patch
+        from .patch import unpatch
 
         __all__ = ["patch", "unpatch"]
